import { Col, Container, Row, Stack } from 'react-bootstrap';
import { Occurrence, Tag } from '../types/tag';
import { ChangeEvent, useContext, useState } from 'react';

import 'antd/dist/antd.css';
import { Button, Input } from 'antd';
import {
    PlusOutlined,
    EyeOutlined,
    DownOutlined,
    DeleteOutlined,
} from '@ant-design/icons';
import { AnnotationContext } from '../../contexts/AnnotationContext';

export function AnnotationItem(props: { tag: Tag }) {
    const [visibleProperties, setVisibleProperties] = useState(false);
    const {
        addOccurrence,
        deleteOccurrence,
        changeVisibility,
        changePosition,
        changeLength,
    } = useContext(AnnotationContext);

    const onAddOccurrence = () => {
        addOccurrence(props.tag);
    };

    const onDeleteOccurrence = (occurrence: Occurrence) => (e: any) => {
        deleteOccurrence(occurrence);
    };

    const onChangeVisibility = () => {
        changeVisibility(props.tag);
    };

    const onChangePosition =
        (occurrence: Occurrence) => (e: ChangeEvent<HTMLInputElement>) => {
            changePosition(occurrence, Number(e.currentTarget.value));
        };

    const onChangeLength =
        (occurrence: Occurrence) => (e: ChangeEvent<HTMLInputElement>) => {
            changeLength(occurrence, Number(e.currentTarget.value));
        };

    const changePropertiesVisibility = () => {
        setVisibleProperties(!visibleProperties);
    };

    return (
        <Container>
            <Row>
                <Col className="d-flex align-items-center">{props.tag.name}</Col>
                <Col sm="auto">
                    <Button
                        type="text"
                        shape="circle"
                        icon={<PlusOutlined />}
                        onClick={onAddOccurrence}
                    />
                    <Button
                        type="text"
                        shape="circle"
                        icon={<EyeOutlined />}
                        onClick={onChangeVisibility}
                    />
                    <Button
                        type="text"
                        shape="circle"
                        icon={<DownOutlined />}
                        onClick={changePropertiesVisibility}
                    />
                </Col>
            </Row>
            {visibleProperties && (
                <Stack>
                    <div>Kategorie: {props.tag.category}</div>
                    <div>Výskyty:</div>
                    {props.tag.occurrences.map((occurrence, index) => {
                        return (
                            <div key={index} id={props.tag.name + index}>
                                <Container>
                                    <Row>
                                        <Col>
                                            <Row>
                                                <Col className="d-flex align-items-center">
                                                    Pozice:
                                                </Col>
                                                <Col sm="auto">
                                                    <Input
                                                        value={occurrence.position}
                                                        onChange={onChangePosition(
                                                            occurrence
                                                        )}
                                                    />
                                                </Col>
                                            </Row>
                                            <Row>
                                                <Col className="d-flex align-items-center">
                                                    Délka:
                                                </Col>
                                                <Col sm="auto">
                                                    <Input
                                                        value={occurrence.length}
                                                        onChange={onChangeLength(
                                                            occurrence
                                                        )}
                                                    />
                                                </Col>
                                            </Row>
                                        </Col>
                                        <Col
                                            sm="auto"
                                            className="d-flex align-items-center"
                                        >
                                            <Button
                                                icon={<DeleteOutlined />}
                                                onClick={onDeleteOccurrence(occurrence)}
                                            ></Button>
                                        </Col>
                                    </Row>
                                </Container>
                            </div>
                        );
                    })}
                </Stack>
            )}
        </Container>
    );
}
